@@ -1,8 +1,8 @@
 # BEGIN BPS TAGGED BLOCK {{{
 # 
 # COPYRIGHT:
-#  
-# This software is Copyright (c) 1996-2009 Best Practical Solutions, LLC 
+# 
+# This software is Copyright (c) 1996-2009 Best Practical Solutions, LLC
 #                                          <jesse@bestpractical.com>
 # 
 # (Except where explicitly superseded by other copyright notices)
@@ -45,15 +45,13 @@
 # those contributions and any derivatives thereof.
 # 
 # END BPS TAGGED BLOCK }}}
+
 package RT::Condition::BeforeDue;
-require RT::Condition::Generic;
+use base 'RT::Condition';
 
 use RT::Date;
 
 use strict;
-use vars qw/@ISA/;
-@ISA = qw(RT::Condition::Generic);
-
 
 sub IsApplicable {
     my $self = shift;
