@@ -160,11 +160,11 @@ sub callback {
 
         my %seen;
         @$callbacks = (
-            sort grep defined && length,
+            grep defined && length,
             # Skip backup files, files without a leading package name,
             # and files we've already seen
             grep !$seen{$_}++ && !m{/\.} && !m{~$} && m{^/Callbacks/[^/]+\Q$page/$name\E$},
-            map $self->interp->resolver->glob_path($path, $_),
+            map { sort $self->interp->resolver->glob_path($path, $_) }
             @roots
         );
         foreach my $comp (keys %seen) {
